Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Domain string
Entries []string
Concurrency int
Timeout time.Duration
DNSServer string
Simulate bool
HitRate int
Attempts int
Force bool
Verbose bool
}
Config holds all parameters needed to run a subdomain scan.
type Event ¶
type Event struct {
Kind EventKind
Domain string // EventResult: the resolved subdomain
Processed int64 // EventProgress
Total int64 // EventProgress
Found int64 // EventProgress / EventDone
Message string // EventError / EventWildcard
}
Event is emitted on the events channel during a scan.
Click to show internal directories.
Click to hide internal directories.